# streamlit_lyrics_sync

A compoennt for syncing lyrics to an audio waveform

## Installation

```bash
pip install streamlit_lyrics_sync
```


## Development

To develop the component, run the following command:

```bash
streamlit run streamlit_lyrics_sync/__init__.py
```

Then run the frontend development server:

```bash
cd streamlit_lyrics_sync/frontend
npm run dev
```

This will start the streamlit development server.

## Building

To build the component, run the following command: